=====================
Appendix C. Changelog
=====================
:Info: This is the changelog for rebookmaker.
:Author: Shlomi Fish <shlomif@cpan.org>
:Copyright: © 2020, Shlomi Fish.
:License: BSD (see /LICENSE or :doc:`Appendix B <LICENSE>`.)
:Date: 2020-07-29
:Version: 0.4.0

.. index:: CHANGELOG

GitHub holds releases, too
==========================

More information can be found on GitHub in the `releases section
<https://github.com/shlomif/rebookmaker/releases>`_.

Version History
===============

0.1.0
    Initial release.
